import { defineStore } from 'pinia';
import { useLayoutStore } from './layout';

export const useMapStore = defineStore('mapState', {
    state: () => ({
        map: Object,
        defaultZoomDesktop: Number,
        defaultZoomMobile: Number,
        defaultMapCenter: Object,
        currentPlace: Object,
        maxZoom: Number,
        currentZoom: Number,
        duration: 3,
    }),
    actions: {
        zoomToPlace(lat, long) {
            if (useLayoutStore().isDesktop) long = long - 0.03;
            this.map.flyTo([lat, long], this.maxZoom, { duration: this.duration });
            this.currentZoom = this.maxZoom;            
        },
        resetMap() {
            this.map.flyTo(this.defaultMapCenter, useLayoutStore().isDesktop ? this.defaultZoomDesktop : this.defaultZoomMobile, { duration: this.duration });
            this.currentZoom = useLayoutStore().isDesktop ? this.defaultZoomDesktop : this.defaultZoomMobile;
        },
        lockMap() {
            setTimeout(() => {
                this.map.options.minZoom = this.currentZoom;
                this.map.options.maxZoom = this.currentZoom;
            }, this.duration * 1000 + 100);
            this.map.dragging.disable();
            this.map.touchZoom.disable();
            this.map.doubleClickZoom.disable();
            this.map.scrollWheelZoom.disable();
            this.map.boxZoom.disable();
            this.map.keyboard.disable();
            // map.tap.disable();
          },
          unlockMap() {
            this.map.options.minZoom = useLayoutStore().isDesktop ? this.defaultZoomDesktop : this.defaultZoomMobile;
            this.map.options.maxZoom = this.maxZoom;
            this.map.dragging.enable();
            this.map.touchZoom.enable();
            this.map.doubleClickZoom.enable();
            this.map.scrollWheelZoom.enable();
            this.map.boxZoom.enable();
            this.map.keyboard.enable();
            // map.tap.enable();
          },
    },
});